==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_fields/PARTNERDFSCATALOGID_Type.java <==

package net.datastream.schemas.mp_fields;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for PARTNERDFSCATALOGID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="PARTNERDFSCATALOGID_Type">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ENDPOINTID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PARTNERDFSCATALOGID_Type", propOrder = {
    "endpointid",
    "description"
})
public class PARTNERDFSCATALOGID_Type {

    @XmlElement(name = "ENDPOINTID")
    protected String endpointid;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the endpointid property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENDPOINTID() {
        return endpointid;
    }

    /**
     * Sets the value of the endpointid property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENDPOINTID(String value) {
        this.endpointid = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-12.2-8-sources.jar: net/datastream/schemas/mp_fields/PARTNERDFSCATALOGID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for PARTNERDFSCATALOGID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="PARTNERDFSCATALOGID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENDPOINTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PARTNERDFSCATALOGID_Type", propOrder = {
    "endpointid",
    "description"
})
public class PARTNERDFSCATALOGID_Type {

    @XmlElement(name = "ENDPOINTID")
    protected String endpointid;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the endpointid property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENDPOINTID() {
        return endpointid;
    }

    /**
     * Sets the value of the endpointid property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENDPOINTID(String value) {
        this.endpointid = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
